@@ -61,9 +61,13 @@ intersphinx_mapping.update(
     ),
 )
 
-# Workaround for #316
 nitpick_ignore = [
+    # Workaround for #316
     ('py:class', 'importlib_metadata.EntryPoints'),
     ('py:class', 'importlib_metadata.SelectableGroups'),
     ('py:class', 'importlib_metadata._meta._T'),
+    # Workaround for #435
+    ('py:class', '_T'),
+    # Other workarounds
+    ('py:class', 'importlib_metadata.DeprecatedNonAbstract'),
 ]
